# PySender
![](https://img.shields.io/pypi/pyversions/PySender)
![](https://img.shields.io/pypi/l/PySender)

## What is it?
### PyQt app to send REST API requests
### PyPi - [PySender](https://pypi.org/project/PySender/)
![screenshot](https://github.com/fast-geek/PySender/raw/master/screenshot.png)

## Main features:
* #### GET, POST, PUT and other requests types
* #### Basic and Digest authentication
* #### Custom headers
* #### JSON response with status code
* #### And not only 😉

## The latest version and updates

##### You can find the latest binaries on [Github repository releases](https://github.com/fast-geek/PySender/releases)

## Installation

### First method (Recommended)
* #### Download program executable from [Github repository releases](https://github.com/fast-geek/PySender/releases)
* #### Open it (unzip if needed first)

### Second method
* #### Open your terminal/CMD
* #### Install PySender via ```pip3 install PySender```

## Requirements

* ##### OS Independent
* ##### Python >= 3.6.1